@@ -43,7 +43,7 @@ using namespace std;
 
 InterfaceDlg::InterfaceDlg(QWidget *parent) :QDialog(parent,"Props", TRUE)
 {
-	setCaption(i18n("Arts: Structureport View"));
+	setCaption(i18n("aRts: Structureport View"));
 
 	QVBoxLayout *mainlayout = new QVBoxLayout(this);
 	//QHBoxLayout *contentslayout = new QHBoxLayout;
@@ -55,7 +55,7 @@ InterfaceDlg::InterfaceDlg(QWidget *parent) :QDialog(parent,"Props", TRUE)
 	QFont labelfont(objectlabel->font());
 	labelfont.setPointSize(labelfont.pointSize()*3/2);
 	objectlabel->setFont(labelfont);
-	objectlabel->setText(QString(" ")+i18n("Object Type: ")+QString(port->owner->name())+QString(" "));
+	objectlabel->setText(QString(" ")+i18n("Object type: ")+QString(port->owner->name())+QString(" "));
 	objectlabel->setAlignment(AlignCenter);
 	min_size(objectlabel);
 	mainlayout->addWidget(objectlabel);
@@ -68,7 +68,7 @@ InterfaceDlg::InterfaceDlg(QWidget *parent) :QDialog(parent,"Props", TRUE)
 	QLabel *portlabel = new QLabel(this);
 	labelfont.setPointSize(labelfont.pointSize()*4/5);
 	portlabel->setFont(labelfont);
-	portlabel->setText(i18n("Port Description: ")+ port->description);
+	portlabel->setText(i18n("Port description: ")+ port->description);
 	min_size(portlabel);
 	portlabel->setAlignment(AlignCenter);
 	mainlayout->addWidget(portlabel);
@@ -112,13 +112,13 @@ InterfaceDlg::InterfaceDlg(QWidget *parent) :QDialog(parent,"Props", TRUE)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(KStdGuiItem::help().text(), this, SLOT( help() ));
+	bbox->addButton(KStdGuiItem::help(), this, SLOT( help() ));
 	bbox->addStretch(1);
 
-	QButton *okbutton = bbox->addButton(KStdGuiItem::ok().text());
+	QButton *okbutton = bbox->addButton(KStdGuiItem::ok());
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
-	QButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel().text());
+	QButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel());
 	connect( cancelbutton, SIGNAL( clicked() ), SLOT(reject() ) );
 
 	bbox->layout();
@@ -160,7 +160,7 @@ void InterfaceDlg::update(const string& interface, const string& indent)
 	listbox->insertItem((indent + interface).c_str());
 
 	vector<string> *children = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
-	for (vector<string>::iterator ci = children->begin(); ci != children->end(); ci++)
+	for (vector<string>::iterator ci = children->begin(); ci != children->end(); ++ci)
 		update(ci->c_str(), indent+"  ");
 	delete children;
 }
