@@ -31,7 +31,7 @@
 namespace Arts {
 
 class KGraphLine_impl;
-class KGraph : virtual public QWidget
+class KGraph : public QWidget
 {
 Q_OBJECT
 
