@@ -15,7 +15,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 #ifndef MIDISEND_H
@@ -45,7 +45,7 @@ class CMidiMap {
 public:
   /*
     Reads in the mapfile pszFileName.
-    Returns TRUE, if successfull.
+    Returns TRUE, if successful.
   */
   bool readMap(const char* pszFileName);
   /*
