@@ -1,4 +1,4 @@
-    /*
+/*
 
     Copyright (C) 2000 Stefan Westerfeld
                        stefan@space.twc.de
@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     Permission is also granted to link this program with the Qt
     library, treating Qt like a library that normally accompanies the
@@ -34,12 +34,15 @@
 #include <stdio.h>
 #include <kaction.h>
 #include <klocale.h>
+#include <kiconloader.h>
 #include <soundserver.h>
 #include "artsmidi.h"
 #include "artsmodules.h"
 #include "midiportdlg.h"
 #include "midiinstdlg.h"
 
+#include <kstdaction.h>
+
 using namespace Arts;
 using namespace std;
 
@@ -47,7 +50,7 @@ using namespace std;
 Arts::Environment::Container defaultEnvironment()
 {
 	Arts::SimpleSoundServer server = Reference("global:Arts_SimpleSoundServer");
-	Arts::Environment::Container d = 
+	Arts::Environment::Container d =
 		Arts::DynamicCast(server._getChild("defaultEnvironment"));
 
 	if(d.isNull())
@@ -78,13 +81,13 @@ public:
 	ConnectionWidget(MidiManagerView *v, QWidget *parent) : QWidget(parent), v(v)
 	{
 	}
-	void paintEvent(QPaintEvent *event)
+	void paintEvent(QPaintEvent * /*event*/)
 	{
 		QPainter painter;
 		painter.begin(this);
 //		painter.fillRect(event->rect(),white);
 
-		int in;
+		unsigned int in;
 		for(in = 0; in < v->widget->inputsListBox->count(); in++)
 		{
 			vector<long>::iterator conn;
@@ -116,23 +119,27 @@ MidiManagerView::MidiManagerView()
 
 	widget = new MidiManagerWidget(this);
 	setCentralWidget(widget);
-    setCaption(i18n("MIDI Manager"));
+	setCaption(i18n("MIDI Manager"));
+	setIcon( MainBarIcon( "artsfftscope", 32 ) );
 
 	(void)new KAction(i18n("&System MIDI Port (OSS)"), 0, this, SLOT(addOSSMidiPort()),
 		  actionCollection(), "add_oss_midi_port");
 	(void)new KAction(i18n("&aRts Synthesis MIDI Output"), 0, this,
-		SLOT(addArtsMidiOutput()), actionCollection(), "add_arts_midi_output");
+		  SLOT(addArtsMidiOutput()), actionCollection(), "add_arts_midi_output");
 
+	(void) KStdAction::quit( this, SLOT(close()), actionCollection());
 	connect(widget->connectButton,SIGNAL(clicked()), this, SLOT(slotConnect()));
 	connect(widget->disconnectButton,SIGNAL(clicked()), this, SLOT(slotDisconnect()));
 
 	connectionWidget = new ConnectionWidget(this, widget->connectionFrame);
 	connectionWidget->setMinimumSize(60,10);
-    widget->connectionFrameLayout->addWidget( connectionWidget, 0, 0 );
+	widget->connectionFrameLayout->addWidget( connectionWidget, 0, 0 );
 
 	updateLists();
-	createGUI("artsmidimanagerview.rc");
+	createGUI( "artsmidimanagerview.rc");
 	show();
+	setCaption(i18n("MIDI Manager"));
+	setIcon( MainBarIcon( "artsfftscope", 32 ) );
 }
 
 void MidiManagerView::closeEvent(QCloseEvent *e)
