@@ -17,6 +17,7 @@
 #include <kdebug.h>
 
 #include <qlayout.h>
+#include <qevent.h>
 
 #include "playlistsplitter.h"
 #include "searchwidget.h"
@@ -35,6 +36,7 @@ using namespace ActionCollection;
 
 PlaylistSplitter::PlaylistSplitter(QWidget *parent, const char *name) :
     QSplitter(Qt::Horizontal, parent, name),
+    m_newVisible(0),
     m_playlistBox(0),
     m_searchWidget(0),
     m_playlistStack(0),
@@ -59,6 +61,15 @@ PlaylistSplitter::~PlaylistSplitter()
     delete m_playlistBox;
 }
 
+bool PlaylistSplitter::eventFilter(QObject *, QEvent *event)
+{
+    if(event->type() == FocusUpEvent::id) {
+        m_searchWidget->setFocus();
+        return true;
+    }
+    return false;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // public slots
 ////////////////////////////////////////////////////////////////////////////////
@@ -68,15 +79,49 @@ void PlaylistSplitter::setFocus()
     m_searchWidget->setFocus();
 }
 
+void PlaylistSplitter::slotFocusCurrentPlaylist()
+{
+    Playlist *playlist = m_playlistBox->visiblePlaylist();
+
+    if(playlist) {
+        playlist->setFocus();
+        playlist->KListView::selectAll(false);
+
+        // Select the top visible (and matching) item.
+
+        PlaylistItem *item = static_cast<PlaylistItem *>(playlist->itemAt(QPoint(0, 0)));
+
+        if(!item)
+            return;
+
+        // A little bit of a hack to make QListView repaint things properly.  Switch
+        // to single selection mode, set the selection and then switch back.
+
+        playlist->setSelectionMode(QListView::Single);
+
+        playlist->markItemSelected(item, true);
+        playlist->setCurrentItem(item);
+
+        playlist->setSelectionMode(QListView::Extended);
+    }
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // private members
 ////////////////////////////////////////////////////////////////////////////////
 
+Playlist *PlaylistSplitter::visiblePlaylist() const
+{
+    return m_newVisible ? m_newVisible : m_playlistBox->visiblePlaylist();
+}
+
 void PlaylistSplitter::setupActions()
 {
     KToggleAction *showSearch =
         new KToggleAction(i18n("Show &Search Bar"), "filefind", 0, actions(), "showSearch");
     showSearch->setCheckedState(i18n("Hide &Search Bar"));
+
+    new KAction(i18n("Edit Track Search"), "edit_clear", "F6", this, SLOT(setFocus()), actions(), "editTrackSearch");
 }
 
 void PlaylistSplitter::setupLayout()
@@ -93,6 +138,7 @@ void PlaylistSplitter::setupLayout()
     QVBoxLayout *topLayout = new QVBoxLayout(top);
 
     m_playlistStack = new QWidgetStack(top, "playlistStack");
+    m_playlistStack->installEventFilter(this);
 
     connect(m_playlistStack, SIGNAL(aboutToShow(QWidget *)), this, SLOT(slotPlaylistChanged(QWidget *)));
 
@@ -123,6 +169,8 @@ void PlaylistSplitter::setupLayout()
     m_searchWidget = new SearchWidget(top, "searchWidget");
     connect(m_searchWidget, SIGNAL(signalQueryChanged()),
             this, SLOT(slotShowSearchResults()));
+    connect(m_searchWidget, SIGNAL(signalDownPressed()),
+            this, SLOT(slotFocusCurrentPlaylist()));
     connect(m_searchWidget, SIGNAL(signalAdvancedSearchClicked()),
             m_playlistBox->object(), SLOT(slotCreateSearchPlaylist()));
     connect(m_searchWidget, SIGNAL(signalShown(bool)),
@@ -178,8 +226,12 @@ void PlaylistSplitter::slotPlaylistChanged(QWidget *w)
 {
     Playlist *p = dynamic_cast<Playlist *>(w);
 
-    if(p)
-        m_searchWidget->setSearch(p->search());
+    if(!p)
+        return;
+
+    m_newVisible = p;
+    m_searchWidget->setSearch(p->search());
+    m_newVisible = 0;
 }
 
 #include "playlistsplitter.moc"
