@@ -3,13 +3,13 @@
 
 #include <kparts/browserextension.h>
 #include <kparts/factory.h>
-
+#include <kdelibs_export.h>
 class KAboutData;
 class KInstance;
 class KMidBrowserExtension;
 class kmidClient;
 
-class KMidFactory : public KParts::Factory
+class KDE_EXPORT KMidFactory : public KParts::Factory
 {
   Q_OBJECT
   public:
