@@ -25,8 +25,8 @@
 #include "mixer.h"
 #include "mixdevicewidget.h"
 
-ViewOutput::ViewOutput(QWidget* parent, const char* name, Mixer* mixer, ViewBase::ViewFlags vflags)
-      : ViewSliders(parent, name, mixer, vflags)
+ViewOutput::ViewOutput(QWidget* parent, const char* name, const QString & caption, Mixer* mixer, ViewBase::ViewFlags vflags)
+      : ViewSliders(parent, name, caption, mixer, vflags)
 {
     init();
 }
@@ -38,7 +38,7 @@ void ViewOutput::setMixSet(MixSet *mixset)
 {
     MixDevice* md;
     for ( md = mixset->first(); md != 0; md = mixset->next() ) {
-	if ( ! md->isRecordable() &&  ! md->isSwitch()) {
+	if ( ! md->isRecordable() &&  ! md->isSwitch() && ! md->isEnum()) {
 	    _mixSet->append(md);
 	}
 	else {
