@@ -10,7 +10,7 @@
 struct audio_oops {
   int (*wmaudio_open)(void);
   int (*wmaudio_close)(void);
-  int (*wmaudio_play)(char*, long, struct cdda_block*);
+  int (*wmaudio_play)(struct cdda_block*);
   int (*wmaudio_stop)(void);
   int (*wmaudio_state)(struct cdda_block*);
   int (*wmaudio_balance)(int);
