@@ -8,7 +8,7 @@
  *
  *  For more information look at the file COPYRIGHT in this package
  *
- * $Id: cdromAccess.cpp,v 1.9 2004/05/11 16:32:08 cartman Exp $
+ * $Id: cdromAccess.cpp 470242 2005-10-13 12:30:28Z mueller $
  *
  */
 
@@ -23,13 +23,7 @@
 #endif
 
 #ifdef OS_Linux
-  #include <linux/version.h>
   #include <sys/types.h>
-  #ifndef __u64
-  #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,70)
-  typedef unsigned long long __u64;
-  #endif
-  #endif
   #include "cdromAccess_Linux.cpp"
 #endif
 
