@@ -17,7 +17,7 @@
 #define MAX_NEG_CROP 32768
 #define NUM_CROP_ENTRIES (2048+2*MAX_NEG_CROP)
 
-#include <iostream.h>
+#include <iostream>
 #include "../util/mmx/mmx.h"
 
 extern "C" {
