@@ -14,7 +14,9 @@
 
 #include "outPlugin.h"
 
+#include <iostream>
 
+using namespace std;
 
 
 OutPlugin::OutPlugin() {
