@@ -72,7 +72,7 @@ QDragObject *EffectList::dragObject() const
 }
 
 EffectView::EffectView()
-	: KDialogBase(0, 0, false, i18n("Effects"), Help | Close, Close, true)
+	: KDialogBase((QWidget*)0L, 0, false, i18n("Effects"), Help | Close, Close, true)
 	, initialized(false)
 {
 }
@@ -163,13 +163,13 @@ void EffectView::init(void)
 	bottomLeftLayout->addWidget(remove);
 	bottomLeftLayout->addStretch();
 
-	
+
 	activeChanged(active->currentItem());
 
 	// Inline documentation
 	QWhatsThis::add(available, i18n("This shows all available effects.\n\nTo activate a plugin, drag files from here to the active pane on the right."));
 	QWhatsThis::add(add, i18n("This will place the selected effect at the bottom of your chain."));
-	QWhatsThis::add(active, i18n("This shows your effect chain. Noatun supports an unlimited amount of effects in any order. You can even have the same effect twice!\n\nDrag the items to and from here to add and remove them, respectively. You may also reorder them with drag-and-drop. These actions can also be performed with the buttons to the right."));
+	QWhatsThis::add(active, i18n("This shows your effect chain. Noatun supports an unlimited amount of effects in any order. You can even have the same effect twice.\n\nDrag the items to and from here to add and remove them, respectively. You may also reorder them with drag-and-drop. These actions can also be performed with the buttons to the right."));
 	QWhatsThis::add(up, i18n("Move the currently selected effect up in the chain."));
 	QWhatsThis::add(down, i18n("Move the currently selected effect down in the chain."));
 	QWhatsThis::add(configure, i18n("Configure the currently selected effect.\n\nYou can change things such as intensity from here."));
@@ -256,7 +256,7 @@ void EffectView::configureEffect()
 {
 	Effect *e = static_cast<EffectListItem*>(active->currentItem())->effect();
 	if(!e) return;
-	
+
 	QWidget *c = e->configure();
 	if(c) c->show();
 }
@@ -268,7 +268,7 @@ void EffectView::activeChanged(QListViewItem *i)
 		up->setEnabled(i->itemAbove());
 		down->setEnabled(i->itemBelow());
 		remove->setEnabled(true);
-		
+
 		Effect *e = static_cast<EffectListItem*>(active->currentItem())->effect();
 		configure->setEnabled(e->configurable());
 	}
