@@ -115,8 +115,9 @@ void Player::play()
 		}
 		else
 		{
-
+			mEngine->blockSignals(true);
 			work=mEngine->open(mCurrent);
+			mEngine->blockSignals(false);
 		}
 	}
 
