@@ -5,8 +5,9 @@
 #include <noatun/plugin.h>
 
 #include <dcopobject.h>
+#include <kdemacros.h>
 
-class NIF : public Plugin, public DCOPObject
+class KDE_EXPORT NIF : public Plugin, public DCOPObject
 {
 K_DCOP
 
