@@ -28,18 +28,19 @@
 #include <config.h>
 #endif
 
-#include <noatun/effects.h>
+#include "systray.h"
+#include "kitsystemtray.h"
+#include "cmodule.h"
+#include "yhconfig.h"
+
 #include <noatun/app.h>
 #include <noatun/pref.h>
 #include <noatun/player.h>
-#include "systray.h"
-#include "kitsystemtray.h"
 #include <noatun/stdaction.h>
-#include "cmodule.h"
 
 #include <kaction.h>
 #include <kconfig.h>
-#include <kfiledialog.h>
+#include <qfile.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -50,7 +51,6 @@
 #include <qhbox.h>
 #include <qpainter.h>
 #include <qpushbutton.h>
-#include <qtimer.h>
 #include <qtooltip.h>
 #include <qvbox.h>
 
@@ -60,23 +60,44 @@
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
+#include <netwm.h>
+#include <kglobalsettings.h>
+
 // TODO: Maybe make this value configurable?
 const int COVER_MAXW = 128;
 const int COVER_MAXH = 128;
 #define BASEICON "noatun"
 
-NoatunSystray *NoatunSystray::self = 0;
-
-NoatunSystray::NoatunSystray()
-	: KMainWindow(0, "NoatunSystray")
-	, Plugin()
-	, trayStatus(0), trayBase(0), mTray(0)
-	, mPassivePopup(0L)
+// From JuK
+class PassivePopup : public KPassivePopup
 {
-	self = this;
+public:
+	PassivePopup(QWidget *parent = 0, const char *name = 0) : KPassivePopup(parent, name) {}
+
+protected:
+	virtual void enterEvent(QEvent *)
+	{
+		setTimeout(3000000); // Make timeout damn near infinite
+	}
+
+	virtual void leaveEvent(QEvent *)
+	{
+		setTimeout(250); // Close quickly
+	}
+};
+
+
+//NoatunSystray *NoatunSystray::self = 0;
+
+
+NoatunSystray::NoatunSystray() : KMainWindow(0, "NoatunSystray"), Plugin(),
+	mTray(0), trayStatus(0), trayBase(0), mPassivePopup(0L)
+{
+	//self = this;
 	hide();
 
 	tmpCoverPath = locateLocal("tmp", "youngHickoryCover.png");
+
 	removeCover(); // make sure any old temp cover is gone
 
 	KStdAction::quit(napp, SLOT(quit()), actionCollection());
@@ -102,14 +123,13 @@ NoatunSystray::NoatunSystray()
 	mTray->changeTitle(*trayBase, i18n("Noatun"));
 	showingTrayStatus = false;
 
-	mBlink = Neither;
-	mBlinkTimer = new QTimer(this, "mBlinkTimer");
+	mBlinkTimer = new QTimer(this);
 	connect(mBlinkTimer, SIGNAL(timeout()), this, SLOT(slotBlinkTimer()));
 
-	connect(napp->player(), SIGNAL(playing()), this, SLOT(slotPlaying()));
+	connect(napp->player(), SIGNAL(playing()), this, SLOT(slotPlayPause()));
+	connect(napp->player(), SIGNAL(paused()), this, SLOT(slotPlayPause()));
 	connect(napp->player(), SIGNAL(stopped()), this, SLOT(slotStopped()));
-	connect(napp->player(), SIGNAL(paused()), this, SLOT(slotPaused()));
-	napp->player()->handleButtons();
+	//napp->player()->handleButtons();
 }
 
 
@@ -125,36 +145,42 @@ NoatunSystray::~NoatunSystray()
 
 void NoatunSystray::init()
 {
-	new YHModule(this);
-	slotBlinkTimer();
+	YHModule *cmod = new YHModule(this);
+	connect(cmod, SIGNAL(saved()), this, SLOT(slotLoadSettings()));
+	slotLoadSettings();
 }
 
 
-void NoatunSystray::setBlink(Blink b)
+void NoatunSystray::slotLoadSettings()
 {
-//	kdDebug(66666) << k_funcinfo << "Called, b=" << (int)b << endl;
+	kdDebug(66666) << k_funcinfo << endl;
 
-	if(mBlink == b)
-		return;
+	YHConfig *c = YHConfig::self();
 
-	mBlink = b;
-
-	if(mBlink == BlinkIcon)
+	if(c->stateIconDisplay() == YHConfig::FlashingIcon)
 		mBlinkTimer->start(1000);
 	else
 		mBlinkTimer->stop();
-
 	slotBlinkTimer();
-}
 
 
-void NoatunSystray::setTip(bool b)
-{
-	mTip = b;
-	if(mTip)
+	if(c->tip())
 		QToolTip::add(mTray, tipText);
 	else
 		QToolTip::remove(mTray);
+
+	if (!c->passivePopupCovers())
+		removeCover();
+
+	if(c->passivePopup())
+	{
+		mPassivePopup = new PassivePopup(mTray, "NoatunPassivePopup");
+	}
+	else
+	{
+		delete mPassivePopup;
+		mPassivePopup = 0L;
+	}
 }
 
 
@@ -166,48 +192,62 @@ void NoatunSystray::closeEvent(QCloseEvent*)
 }
 
 
-void NoatunSystray::slotPlaying()
+void NoatunSystray::slotPlayPause()
 {
-	//mStop->setEnabled(true);
-	changeTray("player_play");
-	const PlaylistItem item = napp->player()->current();
+	QString status;
 
-	if(item.length()>0)
+	if(napp->player()->isPaused())
 	{
-		if(mShowCovers && QFile::exists(tmpCoverPath))
-		{
-			setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-				"<tr><td colspan=2 align=center><nobr><b>Noatun - Playing</b></nobr></td></tr>" \
-				"<tr><td align=center>%1</td><td rowspan=2><img src='%3'></td></tr>" \
-				"<tr><td align=center>%2</td></tr>" \
-				"</table>").arg(item.title(), item.lengthString(), tmpCoverPath));
-		}
-		else
-		{
-			setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-				"<tr><td align=center><nobr><b>Noatun - Playing</b></nobr></td></tr>" \
-				"<tr><td align=center>%1</td</tr>" \
-				"<tr><td align=center>%2</td></tr>" \
-				"</table>").arg(item.title(), item.lengthString()));
-		}
+		changeTray("player_pause");
+		status = i18n("Noatun - Paused");
 	}
 	else
 	{
-		if(mShowCovers && QFile::exists(tmpCoverPath))
+		changeTray("player_play");
+		status = i18n("Noatun - Playing");
+	}
+
+	const PlaylistItem item = napp->player()->current();
+	QString s;
+
+	if(!item.isProperty("title"))
+	{
+		// No metadata
+		s = QString("<nobr>%1</nobr>").arg(item.title());
+	}
+	else
+	{
+		s = QString("<h2><nobr>%1</nobr></h2>").arg(item.property("title"));
+
+		if(item.isProperty("author"))
+			s += QString("<nobr>%1</nobr><br>").arg(item.property("author"));
+
+		if(item.isProperty("album"))
 		{
-			setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-				"<tr><td colspan=2 align=center><nobr><b>Noatun - Playing</b></nobr></td></tr>" \
-				"<tr><td>%1</td><td><img src='%2'></td></tr>" \
-				"</table>").arg(item.title(), tmpCoverPath));
-		}
-		else
-		{
-			setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-				"<tr><td align=center><nobr><b>Noatun - Playing</b></nobr></td></tr>" \
-				"<tr><td>%1</td</tr>" \
-				"</table>").arg(item.title()));
+			if(item.isProperty("date"))
+				s += QString("<nobr>%1 (%2)</nobr><br>").arg(item.property("album")).arg(item.property("date"));
+			else
+				s += QString("<nobr>%1</nobr><br>").arg(item.property("album"));
 		}
 	}
+
+	// prepare cover image for display
+	if (YHConfig::self()->passivePopupCovers())
+		updateCover();
+
+	if(YHConfig::self()->passivePopupCovers() && QFile::exists(tmpCoverPath))
+	{
+		// QT always adds an empty line after the table so we add en empty line before the
+		// table to get equal spacing on top and bottom
+		setTipText(QString("<qt><br><table cellspacing=0 cellpadding=0><tr>" \
+			"<td align=center valign=center><h4><nobr>%1</nobr></h4>%2</td>" \
+			"<td valign=center><img src='%3'></td>" \
+			"</qt></tr></table>").arg(status).arg(s).arg(tmpCoverPath));
+	}
+	else
+	{
+		setTipText(QString("<qt><center><h4><nobr>%1</nobr></h4>%2</center></qt>").arg(status).arg(s));
+	}
 }
 
 
@@ -216,34 +256,10 @@ void NoatunSystray::slotStopped()
 	if(!napp->player()->current())
 		return;
 	changeTray("player_stop");
-	setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-		"<tr><td align=center><nobr><b>Noatun - Stopped</b></nobr></td></tr></table>"));
+	setTipText(QString("<qt><nobr><h4>%1</h4></nobr></qt>").arg(i18n("Noatun - Stopped")));
 }
 
 
-void NoatunSystray::slotPaused()
-{
-	changeTray("player_pause");
-
-	const PlaylistItem item = napp->player()->current();
-
-	if(item.length()>0)
-	{
-		setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-			"<tr><td align=center><nobr><b>Noatun - Paused</b></nobr></td></tr>" \
-			"<tr><td>%1</td></tr>" \
-			"<tr><td>%2</td></tr></table>")
-			.arg(item.title(), item.lengthString()));
-	}
-	else
-	{
-		setTipText(i18n("<table cellspacing=0 cellpadding=0>" \
-			"<tr><td align=center><nobr><b>Noatun - Paused</b></nobr></td></tr>" \
-			"<tr><td>%1</td></tr></table>")
-			.arg(item.title()));
-	}
-}
-
 
 void NoatunSystray::changeTray(const QString &pm)
 {
@@ -256,15 +272,15 @@ void NoatunSystray::changeTray(const QString &pm)
 
 void NoatunSystray::slotBlinkTimer()
 {
-	switch((int)mBlink)
+	switch(YHConfig::self()->stateIconDisplay())
 	{
-		case BlinkIcon:
+		case (YHConfig::FlashingIcon):
 			showingTrayStatus ^= true;
 			break;
-		case ShowIcon:
+		case (YHConfig::StaticIcon):
 			showingTrayStatus = true;
 			break;
-		case Neither:
+		case (YHConfig::NoIcon):
 			showingTrayStatus = false;
 			break;
 	}
@@ -314,15 +330,21 @@ void NoatunSystray::updateCover()
 
 		QImage src;
 		QImage tmpimg;
-		src.load(cover);
 
-		if(src.width() >= COVER_MAXW || src.height() >= COVER_MAXH)
-			tmpimg = src.scale(COVER_MAXW, COVER_MAXH, QImage::ScaleMin);
+		if(src.load(cover))
+		{
+			if(src.width() >= COVER_MAXW || src.height() >= COVER_MAXH)
+				tmpimg = src.scale(COVER_MAXW, COVER_MAXH, QImage::ScaleMin);
+			else
+				tmpimg = src;
+
+			tmpimg.setText("Title", 0, title); //add Title in the image text for cache usage
+			tmpimg.save(tmpCoverPath, "PNG", 0);
+		}
 		else
-			tmpimg = src;
-
-		tmpimg.setText("Title", 0, title); //add Title in the image text for cache usage
-		tmpimg.save(tmpCoverPath, "PNG", 0);
+		{
+			removeCover();
+		}
 	}
 }
 
@@ -330,32 +352,7 @@ void NoatunSystray::updateCover()
 void NoatunSystray::removeCover()
 {
 	if(QFile::exists(tmpCoverPath))
-	{
-//		kdDebug(66666) << k_funcinfo << "Deleting temp cover file" << endl;
 		KIO::NetAccess::del(KURL(tmpCoverPath), this);
-	}
-}
-
-
-void NoatunSystray::setShowCovers(bool show)
-{
-	mShowCovers = show;
-	if (!show)
-		removeCover();
-}
-
-
-void NoatunSystray::setPopupTimeout(int timeout)
-{
-	mPassivePopupTimeout = timeout * 1000;
-	if (mPassivePopup)
-		mPassivePopup->setTimeout(mPassivePopupTimeout);
-}
-
-
-void NoatunSystray::setShowButtons(bool show)
-{
-	mShowButtons = show;
 }
 
 
@@ -363,46 +360,81 @@ void NoatunSystray::setTipText(const QString& text)
 {
 	if(text == tipText) // save the planet, save cpu cycles ;)
 		return;
-
 	tipText = text;
 
-	// prepare cover image for display
-	if (mShowCovers)
-		updateCover();
-
-	if(mPassivePopup)
+	YHConfig *c = YHConfig::self();
+	if(c->passivePopup())
 		QTimer::singleShot(0, this, SLOT(showPassivePopup()));
 
-	if(mTip)
+	if(c->tip())
 		QToolTip::add(mTray, tipText);
 }
 
 
 void NoatunSystray::showPassivePopup()
 {
+	if (!mPassivePopup)
+	{
+		kdDebug(66666) << k_funcinfo << "Called but no KPassivePopup created yet!" << endl;
+		return;
+	}
+
 	mPassivePopup->reparent(0L, QPoint(0,0));
 
-	if (mShowButtons && !napp->player()->isStopped())
+	if (YHConfig::self()->passivePopupButtons() && !napp->player()->isStopped())
 	{
-		QVBox *widget = mPassivePopup->standardView(QString::null, tipText,
-			QPixmap());
-		QHBox *box = new QHBox(mPassivePopup, "popup box");
-		//box->setSpacing(15);
+		QVBox *widget = mPassivePopup->standardView(QString::null, tipText, QPixmap());
+		QHBox *box = new QHBox(mPassivePopup, "popupbox");
 
-		QPushButton *backButton
-			= new QPushButton(action("back")->iconSet(), 0, box, "popup_back");
-		backButton->setFlat(true);
-		connect(backButton, SIGNAL(clicked()), action("back"),
-			SLOT(activate()));
+		box->setSpacing(8);
 
-		widget->reparent(box, QPoint(0, 0));
+		// Algorithm for determining popup location from kpassivepopup.cpp via JuK
+		NETWinInfo ni(qt_xdisplay(), mTray->winId(), qt_xrootwin(),
+			NET::WMIconGeometry | NET::WMKDESystemTrayWinFor);
+		NETRect frame, win;
+		ni.kdeGeometry(frame, win);
 
-		QPushButton *forwardButton = new QPushButton(action("forward")->iconSet(),
-			0, box, "popup_forward");
-		forwardButton->setFlat(true);
-		connect(forwardButton, SIGNAL(clicked()), action("forward"),
-				SLOT(activate()));
+		QRect bounds = KGlobalSettings::desktopGeometry(QPoint(win.pos.x, win.pos.y));
 
+		if(win.pos.x < bounds.center().x())
+		{
+			// Buttons to the left
+
+			QVBox *buttonBox = new QVBox(box);
+			buttonBox->setSpacing(3);
+
+			QPushButton *forwardButton = new QPushButton(action("forward")->iconSet(), 0, buttonBox, "popup_forward");
+			forwardButton->setFlat(true);
+			connect(forwardButton, SIGNAL(clicked()), action("forward"), SLOT(activate()));
+
+			QPushButton *backButton = new QPushButton(action("back")->iconSet(), 0, buttonBox, "popup_back");
+			backButton->setFlat(true);
+			connect(backButton, SIGNAL(clicked()), action("back"), SLOT(activate()));
+
+			QFrame *line = new QFrame(box);
+			line->setFrameShape(QFrame::VLine);
+
+			widget->reparent(box, QPoint(0, 0));
+		}
+		else
+		{
+			// Buttons to the right
+			widget->reparent(box, QPoint(0, 0));
+
+			QFrame *line = new QFrame(box);
+			line->setFrameShape(QFrame::VLine);
+
+			QVBox *buttonBox = new QVBox(box);
+			buttonBox->setSpacing(3);
+
+			QPushButton *forwardButton = new QPushButton(action("forward")->iconSet(), 0, buttonBox, "popup_forward");
+			forwardButton->setFlat(true);
+			connect(forwardButton, SIGNAL(clicked()), action("forward"), SLOT(activate()));
+
+			QPushButton *backButton = new QPushButton(action("back")->iconSet(), 0, buttonBox, "popup_back");
+			backButton->setFlat(true);
+			connect(backButton, SIGNAL(clicked()), action("back"), SLOT(activate()));
+		}
 		mPassivePopup->setView(box);
 	}
 	else
@@ -410,28 +442,11 @@ void NoatunSystray::showPassivePopup()
 		mPassivePopup->setView(QString::null, tipText);
 	}
 
+	mPassivePopup->setTimeout(YHConfig::self()->passivePopupTimeout()*1000);
 	mPassivePopup->show();
 }
 
 
-void NoatunSystray::setPassivePopup(bool pop)
-{
-	if(pop==(mPassivePopup!=0L))
-		return;
-
-	if(pop)
-	{
-		mPassivePopup = new KPassivePopup(mTray, "NoatunPassivePopup");
-		mPassivePopup->setTimeout(mPassivePopupTimeout);
-	}
-	else
-	{
-		delete mPassivePopup;
-		mPassivePopup = 0L;
-	}
-}
-
-
 QPixmap *NoatunSystray::renderIcon(const QString& baseIcon, const QString &overlayIcon) const
 {
 	QPixmap *base = new QPixmap(KSystemTray::loadIcon(baseIcon));
@@ -441,14 +456,6 @@ QPixmap *NoatunSystray::renderIcon(const QString& baseIcon, const QString &overl
 		QPixmap overlay = KSystemTray::loadIcon(overlayIcon);
 		if(!overlay.isNull())
 		{
-			// first combine the masks of both pixmaps (in case both actually have one)
-			if((overlay.mask()!=0) && (base->mask()!=0))
-			{
-				QBitmap mask = *(base->mask());
-				bitBlt(&mask, 0, 0, const_cast<QBitmap *>(overlay.mask()),
-					0, 0, overlay.width(), overlay.height(), Qt::OrROP);
-				base->setMask(mask);
-			}
 			// draw the overlay on top of it
 			QPainter p(base);
 			p.drawPixmap(0, 0, overlay);
